import 'package:analyzer/dart/analysis/analysis_context_collection.dart';
import 'package:analyzer/dart/analysis/results.dart';
import 'package:analyzer/file_system/memory_file_system.dart';
import 'package:analyzer/src/test_utilities/mock_sdk.dart';

void main() async {
  final resourceProvider = MemoryResourceProvider();

  final sdkRoot = resourceProvider.getFolder('/sdk');
  createMockSdk(
    resourceProvider: resourceProvider,
    root: sdkRoot,
  );

  var file = resourceProvider.newFile('/home/test/lib.dart', r'''
class A {
  void foo() {}
}
''');

  final collection = AnalysisContextCollection(
    includedPaths: ['/home'],
    resourceProvider: resourceProvider,
    sdkPath: sdkRoot.path,
  );

  final analysisContext = collection.contextFor(file.path);
  final analysisSession = analysisContext.currentSession;

  final unitElementResult = await analysisSession.getUnitElement(file.path);
  unitElementResult as UnitElementResult;

  var unitElement = unitElementResult.element;
  var libraryElement = unitElement.enclosingElement;
  var A = unitElement.classes[0];
  print(A.lookUpMethod('foo', libraryElement)!.nameOffset);
  print(A.thisType.lookUpMethod2('foo', libraryElement)!.nameOffset);
}
